==> jbossws-framework-3.0.2.GA-testsuite.zip: java/org/jboss/test/ws/jaxws/webfault/CustomException.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.ws.jaxws.webfault;

import javax.xml.ws.WebFault;

/**
 * A custom exception
 *
 * @author alessio.soldano@jboss.com
 * @since 21-Feb-2008
 */
@WebFault(name = "myCustomFault", targetNamespace= "org.jboss.test.ws.jaxws.webfault.exceptions")
public class CustomException extends Exception
{
   private Integer number;
   
   public CustomException(String message, Integer number)
   {
      super(message);
      this.number = number;
   }

   public Integer getNumber()
   {
      return number;
   }

   public void setNumber(Integer number)
   {
      this.number = number;
   }
}

==> jbossws-framework-3.0.3.GA-testsuite.zip: java/org/jboss/test/ws/jaxws/webfault/CustomException.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.ws.jaxws.webfault;

import javax.xml.bind.annotation.XmlTransient;
import javax.xml.ws.WebFault;

/**
 * A custom exception
 *
 * @author alessio.soldano@jboss.com
 * @since 21-Feb-2008
 */
@WebFault(name = "myCustomFault", targetNamespace= "org.jboss.test.ws.jaxws.webfault.exceptions")
public class CustomException extends Exception
{
   private Integer number;
   @XmlTransient
   private String transientString;
   
   public CustomException(String message, Integer number)
   {
      super(message);
      this.number = number;
   }
   
   public CustomException(String message, Integer number, String transientString)
   {
      super(message);
      this.number = number;
      this.transientString = transientString;
   }

   public Integer getNumber()
   {
      return number;
   }

   public void setNumber(Integer number)
   {
      this.number = number;
   }

   public String getTransientString()
   {
      return transientString;
   }

   public void setTransientString(String transientString)
   {
      this.transientString = transientString;
   }
}
